<?php
/**
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA

*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class Rontar extends Module
{
    private $templateFile;
    private $templateFile_name;
    private $hooks = array('displayHeader',
                          );
    private $configurations = array(
                            'RONTAR_ENABLE' => 0,
                            'RONTAR_ADVERTISER_ID' => "",
                            'RONTAR_PRODUCT_FEED_ID' => "",
                            'RONTAR_AUDIENCE_ID' => "");

    public function __construct()
    {
        $this->name = 'rontar';
        $this->author = 'Rontar';
        $this->version = '1.0.0';
        $this->need_instance = 0;
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('Rontar Dynamic Retargeting');
        $this->description = $this->l('Rontar Dynamic Retargeting');
        $this->tab = 'advertising_marketing';
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }

    public function install()
    {
        $install_module =  parent::install();
        if (count($this->hooks) > 0) {
            foreach ($this->hooks as $hook) {
                $rh = (bool)$this->registerHook($hook);
                $install_module = $install_module && $rh;
            }
        }
        if (count($this->configurations) > 0) {
            foreach ($this->configurations as $key => $value) {
                if (is_array($value)) {
                    $lang_array = array();
                    foreach (Language::getLanguages(false) as $lang) {
                        $value_to_array = (isset($value[$lang['id_lang']])) ? $value[$lang['id_lang']] : $value[1];
                        $lang_array[$lang['id_lang']] = $value_to_array;
                    }
                    Configuration::updateValue($key, $lang_array);
                } else {
                    Configuration::updateValue($key, $value);
                }
            }
        }
        
        return $install_module;
    }

    public function uninstall()
    {
        $uninstall_module = parent::uninstall();
        if (count($this->hooks) > 0) {
            foreach ($this->hooks as $hook) {
                $uninstall_module = $uninstall_module & $this->unregisterHook($hook);
            }
        }
        $var1 = "";
        if (count($this->configurations) > 0) {
            foreach ($this->configurations as $key => $val) {
                $var1 = $var1.$val;
                Configuration::deleteByName($key);
            }
        }
        
        return $uninstall_module;
    }

    protected function postProcess()
    {
        parent::postProcess();
    }

    public function getContent()
    {
        $html = '';

            
        if (Tools::getIsset('submitModule')) {
            $errors = array();
            $error_array = array();
            $adv_id = Tools::getValue('RONTAR_ADVERTISER_ID');
            if ($adv_id == "") {
                $error_array[] = $this->l('Advertiser ID required');
            }
            $adv_id = Tools::getValue('RONTAR_PRODUCT_FEED_ID');
            if ($adv_id == "") {
                $error_array[] = $this->l('Product feed ID required”');
            }
            $adv_id = Tools::getValue('RONTAR_AUDIENCE_ID');
            if ($adv_id == "") {
                $error_array[] = $this->l('Audience ID required');
            }
            if (count($error_array) > 0) {
                $html .= $this->displayError(implode('<br />', $error_array));
            }
            
            
            if (count($this->configurations) > 0) {
                foreach ($this->configurations as $key => $value) {
                    if (is_array($value)) {
                        $lang_array = array();
                        foreach (Language::getLanguages(false) as $lang) {
                            $lang_array[$lang['id_lang']] = Tools::getValue($key.'_'.$lang['id_lang']);
                        }
                        Configuration::updateValue($key, $lang_array);
                    } else {
                        Configuration::updateValue($key, Tools::getValue($key));
                    }
                }
            }
            
            if (count($error_array) > 0) {
                Configuration::updateValue('RONTAR_ENABLE', 0);
            }
            
            $errors[] = $this->l('Configuration update');
            $html .= $this->displayConfirmation(implode('<br />', $errors));
        }
        
        $html = $this->renderSignup().$html;
        $html = $this->renderLink().$html;
        
            
        return $html.$this->renderForm();
    }
    
    protected function initForm()
    {
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        
        $this->fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->trans('New value for product', array(), 'Modules.Blockreassurance.Admin'),
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->trans('Advertiser ID', array(), 'Admin.Global'),
                    'lang' => false,
                    'name' => 'RONTAR_ADVERTISER_ID',
                    'cols' => 40,
                    'rows' => 10
                ),
                array(
                    'type' => 'text',
                    'label' => $this->trans('Product feed ID', array(), 'Admin.Global'),
                    'lang' => false,
                    'name' => 'RONTAR_PRODUCT_FEED_ID',
                    'cols' => 40,
                    'rows' => 10
                ),
                array(
                    'type' => 'text',
                    'label' => $this->trans('Audience ID', array(), 'Admin.Global'),
                    'lang' => false,
                    'name' => 'RONTAR_AUDIENCE_ID',
                    'cols' => 40,
                    'rows' => 10
                )
                
            ),
            'submit' => array(
                'title' => $this->trans('Save', array(), 'Admin.Actions'),
            )
        );

        $helper = new HelperForm();
        $helper->module = $this;
        $helper->name_controller = 'rontar';
        $helper->identifier = $this->identifier;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        foreach (Language::getLanguages(false) as $lang) {
            $helper->languages[] = array(
                'id_lang' => $lang['id_lang'],
                'iso_code' => $lang['iso_code'],
                'name' => $lang['name'],
                'is_default' => ($default_lang == $lang['id_lang'] ? 1 : 0)
            );
        }

        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
        $helper->toolbar_scroll = true;
        $helper->title = $this->displayName;
        $helper->submit_action = 'submitModule';
        $helper->toolbar_btn =  array(
            'save' =>
            array(
                'desc' => $this->trans('Save', array(), 'Admin.Actions'),
                'href' => AdminController::$currentIndex.'&configure='.$this->name.
                          '&save'.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules'),
            ),
            'back' =>
            array(
                'href' => AdminController::$currentIndex.'&configure='.
                          $this->name.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->trans('Back to list', array(), 'Admin.Actions'),
            )
        );
        return $helper;
    }
    
    public function renderCronUrl()
    {
        $this->context->smarty->assign(array(
            'cron_url' => $this->context->link->getModuleLink(
                $this->name,
                'cron',
                array('secure_key' => md5(_COOKIE_KEY_.Configuration::get('PS_SHOP_NAME')))
            )
        ));

        return $this->context->smarty->fetch($this->local_path.'views/templates/admin/cron-url.tpl');
    }
    
    public function renderSignup()
    {
        $this->context->smarty->assign(array(
            'cron_url' => $this->context->link->getModuleLink(
                $this->name,
                'cron',
                array('secure_key' => md5(_COOKIE_KEY_.Configuration::get('PS_SHOP_NAME')))
            )
        ));

        return $this->context->smarty->fetch($this->local_path.'views/templates/admin/signup.tpl');
    }
    
    
    public function renderLink()
    {
        $this->context->smarty->assign(array(
            'xmllink' => _PS_BASE_URL_.'/modules/rontar/rontarfeed.php'
        ));

        return $this->context->smarty->fetch($this->local_path.'views/templates/admin/link.tpl');
    }
    
    
    

    protected function renderForm()
    {
                    $fields_form_1 = array(
                        'form' => array(
                            'legend' => array(
                                'title' => $this->l('Settings'),
                                     'icon' => 'icon-cogs'
                                ),
                                'input' => array(
                                        array(
                                                'type' => 'switch',
                                                'is_bool' => true, //retro compat 1.5
                                                'label' => $this->l('Enable'),
                                                'name' => 'RONTAR_ENABLE',
                                                'values' => array(
                                                        array(
                                                            'id' => 'active_on',
                                                            'value' => 1,
                                                                 'label' => $this->l('Enabled')
                                                        ),
                                                        array(
                                                                'id' => 'active_off',
                                                                'value' => 0,
                                                                'label' => $this->l('Disabled')
                                                    )
                                                ),
                                        ),
                                        array(
                                                'type' => 'text',
                                                'label' => $this->l('Advertiser ID'),
                                                'lang' => false,
                                                'name' => 'RONTAR_ADVERTISER_ID',
                                                'cols' => 40,
                                                'rows' => 10
                                        ),
                                        array(
                                            'type' => 'text',
                                            'label' => $this->l('Product feed ID'),
                                            'lang' => false,
                                            'name' => 'RONTAR_PRODUCT_FEED_ID',
                                            'cols' => 40,
                                            'rows' => 10
                                        ),
                                        array(
                                            'type' => 'text',
                                            'label' => $this->l('Audience ID'),
                                            'lang' => false,
                                            'name' => 'RONTAR_AUDIENCE_ID',
                                            'cols' => 40,
                                            'rows' => 10
                                        ),
                                    
                                ),
                                'submit' => array(
                                        'title' => $this->l('Save'),
                                        'class' => 'btn btn-default pull-right',
                                        'name' => 'submitModule',
                                )
                        ),
                );
                $helper = new HelperForm();
                $helper->show_toolbar = false;
                $helper->table = $this->table;
                $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
                $helper->default_form_language = $lang->id;
                $helper->module = $this;
                $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ?
                        Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
                $helper->identifier = $this->identifier;
                $helper->submit_action = 'submitMailAlertConfiguration';
                $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
                .'&configure='.$this->name
                .'&tab_module='.$this->tab
                .'&module_name='.$this->name;
                $helper->token = Tools::getAdminTokenLite('AdminModules');
                $helper->tpl_vars = array(
                        'fields_value' => $this->getConfigFieldsValues(),
                        'languages' => $this->context->controller->getLanguages(),
                        'id_language' => $this->context->language->id
                );
                return $helper->generateForm(array($fields_form_1));
    }
    



    public function getConfigFieldsValues()
    {
        $return_array = array();
        if (count($this->configurations) > 0) {
            foreach ($this->configurations as $key => $value) {
                if (is_array($value)) {
                    foreach (Language::getLanguages(false) as $lang) {
                        $return_array[$key][$lang['id_lang']] =
                                Tools::getValue($key.'_'.$lang['id_lang'], Configuration::get($key, $lang['id_lang']));
                    }
                } else {
                    $return_array[$key] = Tools::getValue($key, Configuration::get($key));
                }
            }
        }
                
        
        if (Tools::getValue("RONTAR_ADVERTISER_ID", Configuration::get("RONTAR_ADVERTISER_ID")) == "" or
           Tools::getValue("RONTAR_PRODUCT_FEED_ID", Configuration::get("RONTAR_PRODUCT_FEED_ID")) == "" or
           Tools::getValue("RONTAR_AUDIENCE_ID", Configuration::get("RONTAR_AUDIENCE_ID")) == "") {
            $return_array["RONTAR_ENABLE"] = 0;
        }
        
        return $return_array;
    }
    
    public function hookdisplayHeader($params)
    {
        if (Configuration::get('RONTAR_ENABLE') == 1) {
            $this->smarty->assign('ADVERTISER_ID', Configuration::get('RONTAR_ADVERTISER_ID'));
            $this->smarty->assign('PRODUCT_FEED_ID', Configuration::get('RONTAR_PRODUCT_FEED_ID'));
            $this->smarty->assign('AUDIENCE_ID', Configuration::get('RONTAR_AUDIENCE_ID'));

            $php_self = $this->context->controller->php_self;
            if ($php_self == 'index') {
                $this->smarty->assign('type', 'index');
            } elseif ($php_self == 'product') {
                $this->smarty->assign('type', 'product');
                $this->smarty->assign('PRODUCT_ID', (int)Tools::getValue('id_product'));
            } elseif ($php_self == 'category') {
                $this->smarty->assign('type', 'category');
                $id_category = (int)Tools::getValue('id_category');
                $this->smarty->assign('CATEGORY_ID', $id_category);
                $category_object = new Category($id_category);
               
                $id_lang = (int) Configuration::get('PS_LANG_DEFAULT');
                
                $products_ids = "";
                if (Validate::isLoadedObject($category_object)) {
                    $products = $category_object->getProducts($id_lang, 1, 20);
                    if (count($products) > 0) {
                        foreach ($products as $prod) {
                            if ($products_ids != "") {
                                $products_ids .= ",";
                            }
                            $products_ids .= $prod['id_product'];
                        }
                    }
                }
                $this->smarty->assign('PRODUCTS_IDS', $products_ids);
            } elseif ($php_self == 'order-confirmation') {
                $id_order = (int) (Tools::getValue('id_order', 0));
                $order = new Order($id_order);
                $products_ids = "";
                if (Validate::isLoadedObject($order)) {
                    $products = $order->getProducts();
                    if (count($products) > 0) {
                        foreach ($products as $prod) {
                            if ($products_ids != "") {
                                $products_ids .= ",";
                            }
                            $products_ids .= $prod['product_id'];
                        }
                    }
                }
                $this->smarty->assign('PRODUCTS_IDS', $products_ids);
                
                $this->smarty->assign('type', 'order-confirmation');
            } elseif ($php_self == 'cart' or $php_self == 'order-opc'  or $php_self == 'order') {
                $this->smarty->assign('type', 'cart');
                $products_ids = "";
                if (isset($this->context->cart->id)) {
                    $id_cart = $this->context->cart->id;
                    $cart = new Cart($id_cart);
                    if (Validate::isLoadedObject($cart)) {
                        $products = $cart->getProducts();
                        if (count($products) > 0) {
                            foreach ($products as $prod) {
                                if ($products_ids != "") {
                                    $products_ids .= ",";
                                }
                                $products_ids .= $prod['id_product'];
                            }
                        }
                    }
                }
                
                $this->smarty->assign('PRODUCTS_IDS', $products_ids);
            } else {
                $this->smarty->assign('type', 'other');
            }
            return $this->display(__FILE__, 'views/templates/front/rontar.tpl');
        }
    }
                
    
    public static function cronProcess()
    {
        $context = Context::getContext();
        
        PrestaShopLogger::addLog('Rontar3 - ', 1, null, 'CDB', 10, true);
        
        $dom = new DomDocument('1.0', 'utf-8');
        
        $shop = $dom->appendChild($dom->createElement('shop'));
        
        $currencies = $shop->appendChild($dom->createElement('currencies'));
        
        $currencies_array = Currency::getCurrencies();
        foreach ($currencies_array as $cur) {
            $currency = $currencies->appendChild($dom->createElement('currency'));
            $currency->setAttribute('id', $cur['iso_code']);
            $currency->setAttribute('rate', $cur['conversion_rate']);
        }
        
        
        $id_lang = (int) Configuration::get('PS_LANG_DEFAULT');
        
        $categories = $shop->appendChild($dom->createElement('categories'));
        
        $categories_array = Db::getInstance()->executeS('select c.id_category, c.id_parent, cl.name from '.
                _DB_PREFIX_.'category c, '._DB_PREFIX_.
                'category_lang cl where c.active = 1 and c.id_category = cl.id_category and cl.id_lang='.
                $id_lang.' order by c.id_category');
        foreach ($categories_array as $cat) {
            $category = $categories->appendChild($dom->createElement('category'));
            $category->setAttribute('id', $cat['id_category']);
            if ((int)$cat['id_parent'] > 0) {
                $category->setAttribute('parentId', $cat['id_parent']);
            }
            $category->appendChild($dom->createTextNode($cat['name']));
        }
        
        $products_array = Db::getInstance()->executeS('select p.id_product from '.
                _DB_PREFIX_.'product p where p.active = 1 order by p.id_product');
        
        $offers = $shop->appendChild($dom->createElement('offers'));
        foreach ($products_array as $prod) {
            $prod_ob = new Product($prod['id_product'], true, $id_lang);
            if (Validate::isLoadedObject($prod_ob)) {
                $offer = $offers->appendChild($dom->createElement('offer'));
                $offer->setAttribute('id', $prod_ob->id);

                $lc = Category::getLinkRewrite($prod_ob->id_category_default, $id_lang);
                $defpa = $prod_ob->getDefaultIdProductAttribute();
                $product_link =
                        $context->link->getProductLink($prod_ob, null, $lc, null, null, null, $defpa);
                $product_link_exp = explode("#", $product_link);
                $url = $offer->appendChild($dom->createElement('url'));
                $url->appendChild($dom->createTextNode($product_link_exp[0]));
                
                $defpa = $prod_ob->getDefaultIdProductAttribute();
                $current_price = Product::getPriceStatic((int)$prod_ob->id, true, $defpa);
                $price = $offer->appendChild($dom->createElement('price'));
                $current_price = number_format($current_price, 2, '.', '');
                $price->appendChild($dom->createTextNode($current_price));
                
                
                $categories_ids = $prod_ob->getCategories();
                $categories_ids = implode(",", $categories_ids);
                $categoryId = $offer->appendChild($dom->createElement('categoryId'));
                $categoryId->appendChild($dom->createTextNode($prod_ob->id_category_default));
                
                
                
                $cover_image = "";
                $image = Product::getCover($prod_ob->id);
                if ((int)$image['id_image'] > 0) {
                    $cover_image = _PS_BASE_URL_.'/img/p/'.
                            Image::getImgFolderStatic($image['id_image']).$image['id_image'].'.jpg';
                }
                $imageURL = $offer->appendChild($dom->createElement('picture'));
                $imageURL->appendChild($dom->createTextNode($cover_image));
                
                $name = $offer->appendChild($dom->createElement('name'));
                $name->appendChild($dom->createTextNode($prod_ob->name));
                
                $description = $offer->appendChild($dom->createElement('description'));
                $description->appendChild($dom->createTextNode(strip_tags($prod_ob->description_short)));
            }
        }
        $dom->formatOutput = true;
        $dom->preserveWhiteSpace = false;
        $dom->saveXML();
        header("Content-Type: text/xml");
        
        echo $dom->saveXML();
        
        return true;
    }
}
